@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GeckoPrintSession.cpp,v 1.4 2006/12/04 22:10:37 chpe Exp $
+ *  $Id: GeckoPrintSession.cpp 6844 2007-01-23 17:41:33Z chpe $
  */
 
 #include "mozilla-config.h"
@@ -105,7 +105,7 @@ GeckoPrintSession::SetSettings (GtkPrintSettings *aSettings,
   NS_ASSERTION (!mSettings && !mPageSetup && !mPrinter, "Already have settings!");
 
   NS_ENSURE_ARG (aSettings);
-  mSettings = aSettings; /* this one is adopted */
+  mSettings = (GtkPrintSettings *) g_object_ref (aSettings);
 
   NS_ENSURE_ARG (aPageSetup);
   NS_ENSURE_ARG (aPrinter);
@@ -490,7 +490,7 @@ GeckoPrintSession::OpenProgressDialog (nsIDOMWindowInternal *aParent,
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_box_set_spacing (GTK_BOX (dialog->vbox), 14); /* 2 * 5 + 14 = 24 */
-  gtk_box_set_spacing (GTK_BOX (dialog->action_area), 6);
+  gtk_box_set_spacing (GTK_BOX (dialog->action_area), 5);
 
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
