@@ -1,6 +1,7 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2001, 2004 Philip Langdale
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2001, 2004 Philip Langdale
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GlobalHistory.cpp,v 1.45 2006/05/10 18:07:00 chpe Exp $
+ *  $Id: GlobalHistory.cpp 6741 2006-12-17 03:06:15Z bjornl $
  */
 
 #include "mozilla-config.h"
@@ -196,13 +197,9 @@ MozGlobalHistory::SetURIGeckoFlags(nsIURI *aURI,
 	EphyNode *page = ephy_history_get_page (mGlobalHistory, spec.get());
 	if (page != NULL)
 	{
-		GValue value = { 0, };
-
-		g_value_init (&value, G_TYPE_LONG);
-		g_value_set_long (&value, (long) (gulong) aFlags);
-		ephy_node_set_property (page, EPHY_NODE_PAGE_PROP_GECKO_FLAGS, &value);
-		g_value_unset (&value);
-
+		ephy_node_set_property_long (page,
+					     EPHY_NODE_PAGE_PROP_GECKO_FLAGS,
+					     aFlags);
 		return NS_OK;
 	}
 
